@@ -55,23 +55,18 @@ Or
 
 Or
 
-    # init myapp logger with accessor LOG
+    # create a application wide logger
     package MyApp;
-    use Log::Handler myapp => "LOG";
+    use Log::Handler;
+    my $log = Log::Handler->create_logger("myapp");
+    $log->add(screen => { maxlevel => "info" });
+    $log->info("info message");
 
-    LOG->add(screen => { maxlevel => "info" });
-    LOG->info("info message");
-
-    # import myapp logger with accessor LOG
-    package MyApp::Foo;
-    use Log::Handler myapp => "LOG";
-    LOG->info("info message from MyApp::Foo");
-
-    # get myapp logger with get_logger()
-    package MyApp::Bar;
+    # get logger with get_logger()
+    package MyApp::Admin;
     use Log::Handler;
     my $log = Log::Handler->get_logger("myapp");
-    $log->info("info message from MyApp::Bar");
+    $log->info("info message from MyApp::Admin");
 
 =head1 DESCRIPTION
 
@@ -357,7 +352,7 @@ placeholders in C<printf()> style. The available placeholders are:
     %r   Runtime in seconds since program start
     %t   Time measurement - replaced with the time since the last call of $log->$level
     %m   Message
-    %%   Procent
+    %%   Percent
 
 The default message layout is set to S<"%T [%L] %m">.
 
@@ -523,7 +518,7 @@ If you set C<die_on_errors> to 0 then you have to controll it yourself.
 This option is set to 1 by default.
 
 Take a look to the decription of the method C<reload> for more
-informations to this option.
+information about this option.
 
 =item B<filter_message>
 
@@ -632,7 +627,7 @@ You can set an alias if you want to get the output object later. Example:
 
 =item B<debug_trace>
 
-You can activate a debugger that writes C<caller()> informations for each
+You can activate a debugger that writes C<caller()> information about each
 active log level. The debugger is logging all defined values except C<hints>
 and C<bitmask>. Set C<debug_trace> to 1 to activate the debugger.
 The debugger is set to 0 by default.
@@ -711,7 +706,7 @@ Output:
 
 =item B<debug_skip>
 
-This option let skip the C<caller()> informations the count of C<debug_skip>.
+This option let skip the C<caller()> information the count of C<debug_skip>.
 
 =back
 
@@ -724,7 +719,7 @@ It's possible to access a output directly:
 
     $log->output($alias)->log(message => "booo");
 
-For more informations take a look to the option C<alias>.
+For more information take a look to the option C<alias>.
 
 =head2 flush()
 
@@ -806,7 +801,7 @@ The key S<"default"> is used here to define default parameters for all file
 outputs. All other keys (C<error_log>, C<common_log>) are used as aliases.
 
 Take a look into the documentation of L<Log::Handler::Config> for more
-informations.
+information.
 
 =head2 reload()
 
@@ -937,7 +932,7 @@ Note: valid character for the key name are: C<[%\w\-\.]+>
 
 With this method it's possible to change the log level at runtime.
 
-To change the log level it's neccessary to use a alias - see option C<alias>.
+To change the log level it's necessary to use a alias - see option C<alias>.
 
     $log->set_level(
         $alias => { # option alias
@@ -953,10 +948,6 @@ logger.
 
     my $log = Log::Handler->create_logger("myapp");
 
-If you want to create more than one object you can call
-
-    my @logger = Log::Handler->create_logger("myapp1", "myapp2", ...);
-
 =head2 get_logger()
 
 With C<get_logger()> it's possible to get a logger that was created
@@ -968,60 +959,6 @@ Just call
 
     my $log = Log::Handler->get_logger("myapp");
 
-Or
-
-    my @logger = Log::Handler->get_logger("myapp1", "myapp2", ...);
-
-=head1 GLOBAL LOG HANDLER
-
-Since version C<0.50> it's possible to define a application logger.
-This means to create a C<Log::Handler> object and import it into
-all modules of your project.
-
-    use Log::Handler alias => accessor;
-
-The accessor is created into the namespace of the caller and
-referenced to the alias.
-
-If the alias doesn't exists then a new C<Log::Handler> object
-will be created.
-
-If no accesseor is set then no accessor is exported into the
-namespace of the caller.
-
-Example:
-
-    package MyAPP;
-    use strict;
-    use warnings;
-    use Log::Handler myapp => "LOG";
-
-    LOG->config(config => "myapp.conf");
-    LOG->info("hello world");
-
-Now you can access the logger after you import it.
-
-    package MyAPP::Foo; 
-    use Log::Handler myapp => "LOG";
-
-    LOG->info("message");
-
-If you want to import another accessor name ...
-
-    package MyAPP::Bar;
-    use Log::Handler myapp => "MYLOG";
-
-    MYLOG->info("message");
-
-Another way to get the logger is to call C<get_logger()> if you
-don't want to create an accessor.
-
-    package MyAPP::Foo::Bar;
-    use Log::Handler;
-
-    my $log = Log::Handler->get_logger("myapp");
-    $log->info("message");
-
 =head1 EXAMPLES
 
 L<Log::Handler::Examples>
@@ -1114,7 +1051,7 @@ use Log::Handler::Pattern;
 use UNIVERSAL;
 use base qw(Log::Handler::Levels);
 
-our $VERSION = "0.65";
+our $VERSION = "0.69";
 our $ERRSTR  = "";
 
 # $TRACE and $CALLER_LEVEL are both used as global
@@ -1215,27 +1152,25 @@ sub import {
 }
 
 sub get_logger {
-    @_ > 1 || croak 'Usage: Log::Handler->get_logger($app)';
-    my $class = shift;
+    @_ == 2 || croak 'Usage: Log::Handler->get_logger($app)';
+    my ($class, $logger) = @_;
 
-    foreach my $logger (@_) {
-        if (!exists $LOGGER{$logger}) {
-            croak "logger '$logger' does not exists";
-        }
+    if (!exists $LOGGER{$logger}) {
+        croak "logger '$logger' does not exists";
     }
 
-    return @LOGGER{@_};
+    return $LOGGER{$logger};
 }
 
 sub create_logger {
-    @_ > 1 || croak 'Usage: Log::Handler->create_logger($app)';
-    my $class = shift;
+    @_ == 2 || croak 'Usage: Log::Handler->create_logger($app)';
+    my ($class, $logger) = @_;
 
-    foreach my $logger (@_) {
+    if (!exists $LOGGER{$logger}) {
         $LOGGER{$logger} = __PACKAGE__->new();
     }
 
-    return @LOGGER{@_};
+    return $LOGGER{$logger};
 }
 
 sub new {
@@ -1262,25 +1197,29 @@ sub new {
 }
 
 sub add {
-    my $self = shift;
+    my ($self, @args) = @_;
 
-    if ($_[0] && $_[0] eq "config") {
-        return $self->config(@_);
+    if ($args[0] && $args[0] eq "config") {
+        return $self->config(@args);
     }
 
-    if (@_ > 2) {
-        while (@_) {
-            my $type = shift;
-            my $conf = shift;
+    if (@args > 2) {
+        if (@args % 2 != 0) {
+            Carp::croak 'Odd number of arguments to Log::Handler::add';
+        }
+        while (@args) {
+            my $type = shift @args;
+            my $conf = shift @args;
             $self->add($type, $conf);
         }
+        return 1;
     }
 
     # At first the config will be splitted into
     # the package name (Log::Handler::Output::*),
     # the options for the handler and the options
     # for the output-module.
-    my ($package, $h_opts, $o_opts) = $self->_split_config(@_);
+    my ($package, $h_opts, $o_opts) = $self->_split_config(@args);
 
     # In the next step the handler options
     # must be validated.
@@ -1486,6 +1425,7 @@ sub set_level {
         foreach my $level (keys %{$output->{levels}}) {
             if ($levels->{$level}) {
                 my @old_order = @{$levels->{$level}};
+                push @old_order, $output;
                 $levels->{$level} = [
                     map  { $_->[0] }
                     sort { $a->[1] <=> $b->[1] }
